
# Network

## Clients

PLPipes provides a set of easy-to-use network clients for downloading
data from several institutions.

This is still a work in progress.

### Eurostat

### U.S. Energy Information Administration (EIA)

API key must be dowloaded from
https://www.eia.gov/opendata/register.php and added into the
configuration as `net.client.eia.api_key`.

### European Central Bank (ECB)

### U.S. Bureau of Labor Statistics (BLS)

API key must be downloaded from
https://data.bls.gov/registrationEngine/ and added into the
configuration as `net.client.us_bls.api_key`.

